=======
History
=======

0.5.3 (2017-07-03)
------------------

Fixed
~~~~~
* Fixed FD resource leak in discovery of existing lights.

0.5.2 (2017-07-02)
------------------

Changed
~~~~~~~
* Significant changes. Improvements to the API. Type hints, doc strings, etc.

0.5.1 (2017-06-26)
------------------

* Initial version after fork from https://github.com/frawau/aiolifx
